FSBatchInliner class

A class that inlines Firestorm transactions.

Inheritance

Constructors

FSBatchInliner(dynamic _logic(FSBatchHandler handler))

Properties

create ↔ FSBatchCreateDelegate
latefinalinherited
delete ↔ FSBatchDeleteDelegate
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
update ↔ FSBatchUpdateDelegate
latefinalinherited

Methods

handleBatch() → dynamic
Handles the batch logic.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited