endAt method
Ends the query at a specific document where the field values provided are met.
Implementation
FSFilterable<T> endAt(List<dynamic> fieldValues) {
query = query.endAt(fieldValues);
return this;
}
Ends the query at a specific document where the field values provided are met.
FSFilterable<T> endAt(List<dynamic> fieldValues) {
query = query.endAt(fieldValues);
return this;
}