FSTransactionCreateDelegate class

A delegate class to create documents in Firestore, using transactions.

Constructors

FSTransactionCreateDelegate.init(Transaction _tx, {SetOptions? setOptions})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setOptions → SetOptions?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
one(dynamic object, {String? subcollection}) → Future<Transaction>
Creates a document in Firestore from the given object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited