shutdown static method
Shuts down the RDB instance. If used again, a new instance has to be created by calling RDB.init().
Implementation
static Future<void> shutdown() {
return instance.goOffline();
}
Shuts down the RDB instance. If used again, a new instance has to be created by calling RDB.init().
static Future<void> shutdown() {
return instance.goOffline();
}