FSTypes class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
isFirestoreNativeType(DartType type)
→ bool
-
Checks if the given Dart type is a native Firestore type (e.g., Timestamp, DocumentReference, ...).
-
isSupportedPrimitive(DartType type)
→ bool
-
Checks if the given Dart type is a supported primitive type for Firestore.
-
isTypeSupported(DartType type)
→ bool
-
Checks if the given Dart type is supported by Firestore.
Constants
-
fsNativeTypes
→ const List<String>
-
List of native Firestore types that are directly supported without conversion.